==> skrooge_0.8.1.orig.tar.bz2: skrooge-0.8.1/skgbasegui/skginterfaceplugin.cpp <==
/***************************************************************************
 *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/
/** @file
* This file is a plugin interface default implementation.
*
* @author Stephane MANKOWSKI / Guillaume DE BURE
 */
#include "skginterfaceplugin.h"

SKGInterfacePlugin::SKGInterfacePlugin(QObject * parent)
    : KParts::Plugin(parent)
{}
SKGInterfacePlugin::~SKGInterfacePlugin()
{}

void SKGInterfacePlugin::processArguments(const QStringList& iArgument)
{
    Q_UNUSED(iArgument);
}

void SKGInterfacePlugin::close() {}

void SKGInterfacePlugin::refresh() {}

QDockWidget* SKGInterfacePlugin::getDockWidget()
{
    return NULL;
}

SKGTabPage* SKGInterfacePlugin::getWidget()
{
    return NULL;
}

int SKGInterfacePlugin::getNbDashboardWidgets()
{
    return 0;
}

QString SKGInterfacePlugin::getDashboardWidgetTitle(int iIndex)
{
    Q_UNUSED(iIndex);
    return "";
}

SKGWidget* SKGInterfacePlugin::getDashboardWidget(int iIndex)
{
    Q_UNUSED(iIndex);
    return NULL;
}

QWidget* SKGInterfacePlugin::getPreferenceWidget()
{
    return NULL;
}

KConfigSkeleton* SKGInterfacePlugin::getPreferenceSkeleton()
{
    return NULL;
}

SKGError SKGInterfacePlugin::savePreferences() const
{
    return SKGError();
}

int SKGInterfacePlugin::getOrder() const
{
    return 999;
}

QString SKGInterfacePlugin::statusTip() const
{
    return toolTip();
}

QString SKGInterfacePlugin::icon() const
{
    return "";
}

QString SKGInterfacePlugin::toolTip() const
{
    return title();
}

QStringList SKGInterfacePlugin::tips() const
{
    return QStringList();
}

bool SKGInterfacePlugin::isInContext() const
{
    return false;
}

bool SKGInterfacePlugin::isEnabled() const
{
    return true;
}

QList< SKGInterfacePlugin::SKGAdvice > SKGInterfacePlugin::advices() const
{
    QList< SKGInterfacePlugin::SKGAdvice > output;
    return output;
}

SKGError SKGInterfacePlugin::executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution) const
{
    Q_UNUSED(iAdviceIdentifier);
    Q_UNUSED(iSolution);
    return SKGError(ERR_NOTIMPL, "");
}

#include "skginterfaceplugin.moc"

==> skrooge_1.3.0.orig.tar.bz2: skrooge-1.3.0/skgbasegui/skginterfaceplugin.cpp <==
/***************************************************************************
 *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/
/** @file
* This file is a plugin interface default implementation.
*
* @author Stephane MANKOWSKI / Guillaume DE BURE
 */
#include "skginterfaceplugin.h"

SKGInterfacePlugin::SKGInterfacePlugin(QObject* parent)
    : KParts::Plugin(parent)
{}
SKGInterfacePlugin::~SKGInterfacePlugin()
{}

void SKGInterfacePlugin::processArguments(const QStringList& iArgument)
{
    Q_UNUSED(iArgument);
}

void SKGInterfacePlugin::close() {}

void SKGInterfacePlugin::refresh() {}

QDockWidget* SKGInterfacePlugin::getDockWidget()
{
    return NULL;
}

SKGTabPage* SKGInterfacePlugin::getWidget()
{
    return NULL;
}

int SKGInterfacePlugin::getNbDashboardWidgets()
{
    return 0;
}

QString SKGInterfacePlugin::getDashboardWidgetTitle(int iIndex)
{
    Q_UNUSED(iIndex);
    return "";
}

SKGWidget* SKGInterfacePlugin::getDashboardWidget(int iIndex)
{
    Q_UNUSED(iIndex);
    return NULL;
}

QWidget* SKGInterfacePlugin::getPreferenceWidget()
{
    return NULL;
}

KConfigSkeleton* SKGInterfacePlugin::getPreferenceSkeleton()
{
    return NULL;
}

SKGError SKGInterfacePlugin::savePreferences() const
{
    return SKGError();
}

int SKGInterfacePlugin::getOrder() const
{
    return 999;
}

QString SKGInterfacePlugin::statusTip() const
{
    return toolTip();
}

QString SKGInterfacePlugin::icon() const
{
    return "";
}

QString SKGInterfacePlugin::toolTip() const
{
    return title();
}

QStringList SKGInterfacePlugin::tips() const
{
    return QStringList();
}

bool SKGInterfacePlugin::isInPagesChooser() const
{
    return false;
}

bool SKGInterfacePlugin::isEnabled() const
{
    return true;
}

SKGAdviceList SKGInterfacePlugin::advices() const
{
    SKGAdviceList output;
    return output;
}

SKGError SKGInterfacePlugin::executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution) const
{
    Q_UNUSED(iAdviceIdentifier);
    Q_UNUSED(iSolution);
    return SKGError(ERR_NOTIMPL, "");
}

#include "skginterfaceplugin.moc"
